************************************
Network
************************************

A ``Network`` object holds copies of previously defined populations, projections or monitors in order to simulate them independently.

The ``parallel_run()`` method can be used to simulate different networks in parallel.

Parallel simulations
=====================

.. automethod:: ANNarchy.core.Network.parallel_run

Network class
==============

.. autoclass:: ANNarchy.Network
   :members:
